# from datetime import date
from io import BytesIO

from fastapi import APIRouter, Depends
from fastapi.responses import StreamingResponse

from ..config import Config, get_config
from ._image import AdventImage
from ._misc import get_image, shuffle

router = APIRouter(prefix="/days", tags=["days"])


@router.on_event("startup")
async def startup() -> None:
    cfg = await get_config()
    print(cfg.solution)
    print("".join(await shuffle(cfg.solution)))


@router.get("/letter/{index}")
async def get_letter(
    index: int,
    cfg: Config = Depends(get_config),
) -> str:
    return (await shuffle(cfg.solution))[index]


# @router.get("/date")
# def get_date() -> int:
#     return date.today().day


# @router.get(
#     "/picture",
#     response_class=StreamingResponse,
# )
# async def get_picture():
#     img = Image.open("hand.png").convert("RGBA")
#     d1 = ImageDraw.Draw(img)
#     font = ImageFont.truetype("Lena.ttf", 50)
#     d1.text((260, 155), "W", font=font, fill=(0, 0, 255))
#     # d1.text(xy=(400, 210), text="Deine Hände auch?",
#     #         font=Font, fill=(255, 0, 0))
#     img_buffer = BytesIO()
#     img.save(img_buffer, format="PNG", quality=85)
#     img_buffer.seek(0)

#     return StreamingResponse(
#         content=img_buffer,
#         media_type="image/png",
#     )


@router.get(
    "/picture/{index}",
    response_class=StreamingResponse,
)
async def get_image_for_day(
    image: AdventImage = Depends(get_image),
) -> StreamingResponse:
    """
    Bild für einen Tag erstellen
    """

    # Bilddaten in Puffer laden
    img_buffer = BytesIO()
    image.img.save(img_buffer, format="JPEG", quality=85)
    img_buffer.seek(0)

    return StreamingResponse(
        content=img_buffer,
        media_type="image/jpeg",
    )
